Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'jsf/plugins/org.eclipse.jst.jsf.core/src/org/eclipse/jst/jsf/core/internal/tld/ITLDConstants.java')
-rw-r--r--jsf/plugins/org.eclipse.jst.jsf.core/src/org/eclipse/jst/jsf/core/internal/tld/ITLDConstants.java84
1 files changed, 46 insertions, 38 deletions
diff --git a/jsf/plugins/org.eclipse.jst.jsf.core/src/org/eclipse/jst/jsf/core/internal/tld/ITLDConstants.java b/jsf/plugins/org.eclipse.jst.jsf.core/src/org/eclipse/jst/jsf/core/internal/tld/ITLDConstants.java
index 3ec16f476..ba6843f9f 100644
--- a/jsf/plugins/org.eclipse.jst.jsf.core/src/org/eclipse/jst/jsf/core/internal/tld/ITLDConstants.java
+++ b/jsf/plugins/org.eclipse.jst.jsf.core/src/org/eclipse/jst/jsf/core/internal/tld/ITLDConstants.java
@@ -1,38 +1,46 @@
-/*******************************************************************************
- * Copyright (c) 2001, 2007 Oracle Corporation and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
- * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
- *
- * Contributors:
- * Oracle Corporation - initial API and implementation
- *******************************************************************************/
-package org.eclipse.jst.jsf.core.internal.tld;
-
-/**
- * Global tag library constants
- *
- * @author cbateman
- *
- */
-public interface ITLDConstants {
-
- /**
- * The JSF core (f) component URI
- */
- public static final String URI_JSF_CORE = "http://java.sun.com/jsf/core"; //$NON-NLS-1$
- /**
- * The JSF html (h) component URI
- */
- public static final String URI_JSF_HTML = "http://java.sun.com/jsf/html"; //$NON-NLS-1$
- /**
- * The last component of the html uri
- */
- public static final String URI_HTML = "html"; //$NON-NLS-1$
- /**
- * The last component of the core uri
- */
- public static final String URI_JSP = "jsp"; //$NON-NLS-1$
-
-}
+/*******************************************************************************
+ * Copyright (c) 2001, 2007 Oracle Corporation and others.
+ * All rights reserved. This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License v1.0
+ * which accompanies this distribution, and is available at
+ * http://www.eclipse.org/legal/epl-v10.html
+ *
+ * Contributors:
+ * Oracle Corporation - initial API and implementation
+ *******************************************************************************/
+package org.eclipse.jst.jsf.core.internal.tld;
+
+/**
+ * Global tag library constants
+ *
+ * @author cbateman
+ *
+ */
+public interface ITLDConstants {
+
+ /**
+ * The JSF core (f) component URI
+ */
+ public static final String URI_JSF_CORE = "http://java.sun.com/jsf/core"; //$NON-NLS-1$
+ /**
+ * The JCP version of the JSF core (f) component URI
+ */
+ public static final String URI_JSF_CORE_JCP = "http://xmlns.jcp.org/jsf/core"; //$NON-NLS-1$
+ /**
+ * The JSF html (h) component URI
+ */
+ public static final String URI_JSF_HTML = "http://java.sun.com/jsf/html"; //$NON-NLS-1$
+ /**
+ * The JCP version of the JSF html (h) component URI
+ */
+ public static final String URI_JSF_HTML_JCP = "http://xmlns.jcp.org/jsf/html"; //$NON-NLS-1$
+ /**
+ * The last component of the html uri
+ */
+ public static final String URI_HTML = "html"; //$NON-NLS-1$
+ /**
+ * The last component of the core uri
+ */
+ public static final String URI_JSP = "jsp"; //$NON-NLS-1$
+
+}

Back to the top